//	bit map definition of io mapped registers of ADSP-2191
//	(c) ADKK 2001.
//*********************************************************************
//									HOW TO USE
//*********************************************************************
/*
1. Basic usage
This is bit definition of ADSP-2191 internal Peripherals. To use this 
file, just include from C, C++ or ASM source. Note that this file doesn't
contains Peripheral Address. To use Addres, include def2191.h

2. bit naming rule.
The name of bit follows 2191 Hardware Reference manual. For example, 
page B-106 defines bit 0 of HOSTD_CFG as "DEN". This file also defines
that as DEN.

3. bit field naming rule. 
All bit field has 2 parameter. One is field mask, the other is field
offset. The field mask gives the bit mask which covers the range of 
bit field. You can access bit field mask of any field as XXXX_MASK, 
where XXXX is the name of that field. Foe example, the mask of the 
HOSTD_CFG register(HR B-106)'s bit field FS is given as FS_MASK.

The bit field offset is the distance of bit field from bit 0. This 
can be accessed as XXXX_OFST. Where XXXX is bit field name.For example, 
bit field offset of fieldFS of HOSTD_CFG is 12. You can refere that as 
FS_OFST. 

Some bit field has alternate definition. For example, SLOT field of 
SPx_TCR has definition macro SLOT_MASK and SLOT_OFST. In addtion to 
them, that field has value SLOT_3, SLOT_4,... This type of name is 
not defined exactly in the Hardware Reference. Then, refer this file 
to know the macro name of such the value. 

4. Exceptions. 
Certain bits has same name between defferent peripheral. I have changed
these kind of bits. If you have compile/Assemble error. Please watch 
this file.

bit name of Following registers are re-named:
XXXX_SRP, HPPR, SPI_STx, SP_STATR

5. How to get newest version
You can see the newest version of this file from the web site. Current
URL is 
http://www.analog.co.jp/library/applicationNotes/dsp/eej-007_sample.zip

6. Contact.
If you find error in this file. Please feel free to contact me.
Address is seiichi.horie@analog.com

Horie, Seiichi
ADKK DSP FAE.
2002.Apr.
*/
//*********************************************************************
//							C A U T I O N
//*********************************************************************
/*
	NXTSCR'S OPMODE has dual function. To be easy programming, This 
	file uses bit 0-2 as BMODE insted of 1-2. See HR B-18 and definition
	in this file.
*/
//*********************************************************************
//									HISTORY of Change
//*********************************************************************
/*
2002.Apr.2
first full edition. Thank you Benno for your contribution on UART.
SLOTxx is changed to SLOT_xx
SPx_STATR register's bit name is changed to SPT_xxx
SPI_ST registered's bit name is changed to SPI_xxx
xxxD_SRP registers's bit name is changed to SRP_xxx

2002.May.26
Immediate bit value is substituted by BIT_xx.
Fixed some bugs.

*/
#define BIT_0 0x0001
#define BIT_1 0x0002
#define BIT_2 0x0004
#define BIT_3 0x0008
#define BIT_4 0x0010
#define BIT_5 0x0020
#define BIT_6 0x0040
#define BIT_7 0x0080
#define BIT_8 0x0100
#define BIT_9 0x0200
#define BIT_10 0x0400
#define BIT_11 0x0800
#define BIT_12 0x1000
#define BIT_13 0x2000
#define BIT_14 0x4000
#define BIT_15 0x8000
//*********************************************************************
//
//
//									DMA
//
//
//*********************************************************************
		// Definition for DMA_CFG of commond operation
		// HISTORY of CHNGE FS_xxx is fixed
#define	DOWN		BIT_15
#define	DS			BIT_14
#define	FS_OFST		12
#define	FS_MASK			( 3 << FS_OFST )
#define	FS_EMPTY		( 0 << FS_OFST )
#define	FS_ONE_WORD		( 1 << FS_OFST )
#define	FS_TWO_WORD		( 2 << FS_OFST )
#define	FS_THREE_WORD 	( 3 << FS_OFST )
#define	DERE		BIT_8
#define	FLSH		BIT_7
#define	DAUTO		BIT_4
#define DTYPE		BIT_3
#define	DCOME		BIT_2
#define	TRAN		BIT_1
#define	DEN			BIT_0

		// Definition for xxxD_SRP
#define	SRP_MS_OFST		8
#define	SRP_MS_MASK		( 3 << SRP_MS_OFST )
#define	SRP_MS_MEMORY	( 0 << SRP_MS_OFST )
#define	SRP_MS_BOOT		( 1 << SRP_MS_OFST )
#define	SRP_MS_IO		( 2 << SRP_MS_OFST )
#define	SRP_MP_OFST		0
#define SRP_MP_MASK		( 0x00ff << SRP_MS_OFST )

		// Definition for xxxD_IRQ
#define	DERI		BIT_1
#define	DCOMI		BIT_0

		// SPI DMA dedicated bits
#define MODF		BIT_11
#define	TXE			BIT_10
#define	RBSY		BIT_9

		// UART DMA dedicated bits
#define UARFE		BIT_11
#define	UARPE		BIT_10
#define	UAROE		BIT_9

		// HOST DMA dedicated bits
#define	DRDY		BIT_9

//*********************************************************************
//
//
//									SPORT
//
//
//*********************************************************************

		// Definition for SPx_TCR
		// Caution. SLEN 03-16 mean, size of slot is 3-16
		// Histry of change : SLENxx->SLEN_xx, added SLEN_OFST, SLEN_MASK, DYTPE_OFST, DTYPE_MASK
#define ICLKD 		BIT_15
#define CKRE		BIT_14
#define LATFS		BIT_13
#define LTFS		BIT_12
#define DITFS		BIT_11
#define	TFSR		BIT_10
#define	ITFS		BIT_9
#define SLEN_OFST	5
#define	SLEN_MASK	( 0x0f << SLEN_OFST )
#define SLEN_3		( 2 << SLEN_OFST )
#define SLEN_4		( 3 << SLEN_OFST )
#define SLEN_5		( 4 << SLEN_OFST )
#define SLEN_6		( 5 << SLEN_OFST )
#define SLEN_7		( 6 << SLEN_OFST )
#define SLEN_8		( 7 << SLEN_OFST )
#define SLEN_9		( 8 << SLEN_OFST )
#define SLEN_10		( 9 << SLEN_OFST )
#define SLEN_11		( 10 << SLEN_OFST )
#define SLEN_12		( 11 << SLEN_OFST )
#define SLEN_13		( 12 << SLEN_OFST )
#define SLEN_14		( 13 << SLEN_OFST )
#define SLEN_15		( 14 << SLEN_OFST )
#define SLEN_16		( 15 << SLEN_OFST )
#define SENDN		BIT_4
#define	DTYPE_OFST	2
#define DTYPE_MASK	( 3 << DTYPE_OFST )
#define	DTYPE_ZERO	( 0 << DTYPE_OFST )
#define	DTYPE_SIGN	( 1 << DTYPE_OFST )
#define DTYPE_MU	( 2 << DTYPE_OFST )
#define	DTYPE_A		( 3 << DTYPE_OFST )
#define ICLK		BIT_1
#define	TSPEN		BIT_0
	
		// Definition for SPx_RCR
#define	LRFS		BIT_12
#define RFSR		BIT_10
#define IRFS		BIT_9
#define	RSPEN		BIT_0

		// Definition for SPx_STATR
#define	SPT_CHNL_OFST	4
#define	SPT_CHNL_MASK	( 0x07f << SPT_CHNL_OFST )
#define	SPT_TUVF		BIT_3
#define	SPT_TXS			BIT_2
#define	SPT_RXS			BIT_1
#define	SPT_ROVF		BIT_0

		// Definition for SPx_MCMC1
		// Note WOFF and WSIZE description in ADSP-2191 DSP HW Ref Rev1 is wrong
		// See Reference of ADSP-21535 which employs same module.
#define WOFF_OFST	9
#define	WOFF_MASK	( 0x7f << WOFF_OFST )
#define	WSIZE_OFST	5
#define	WSIZE_MASK	( 0x0f << WSIZE_OFST )
#define	MFD_OFST	1
#define	MFD_MASK	( 0x0f << MFD_OFST )
#define	MCM			1

		// Definition for SPx_MCMC2
#define	FSDR		BIT_7
#define	MCFF_OFST	5
#define MCFF_MASK	( 3 << MCFF_OFST )
#define	MCFF_2CH	( 0 << MCFF_OFST )
#define	MCFF_4CH	( 1 << MCFF_OFST )
#define	MCFF_8CH	( 2 << MCFF_OFST )
#define	MCFF_16CH	( 3 << MCFF_OFST )
#define	MCOM		BIT_4
#define	MCDRXPE		BIT_3
#define	MCDTXPE		BIT_2
#define MCCRM_OFST	0
#define	MCCRM_MASK	( 0x03 << MCCRM_OFST )
#define	MCCRM_BYPASS ( 0 << MCCRM_OFST )
#define	MCCRM_2MHZ	( 2 << MCCRM_OFST )
#define MCCRM_8MHZ	( 3 << MCCRM_OFST )

//*********************************************************************
//
//
//									SPI
//
//
//*********************************************************************

		// Definition for SPICTLx	B-54
#define TIMOD_OFST	0
#define TIMOD_MASK	( 3 << MCCRM_OFST )
#define TIMOD_READ	( 0 << MCCRM_OFST )
#define TIMOD_WRITE	( 1 << MCCRM_OFST )
#define TIMOD_DMA	( 2 << MCCRM_OFST )
#define	SZ			BIT_2
#define	GM			BIT_3
#define	PSSE		BIT_4
#define	EMISO		BIT_5
#define	SIZE		BIT_8
#define LSBF		BIT_9
#define	CPHA		BIT_10
#define	CPOL		BIT_11
#define	MSTR		BIT_12
#define	WOM			BIT_13
#define	SPE			BIT_14

		// Definition for SPIFLG0 B-56
#define	FLS1		BIT_1
#define	FLS2		BIT_2
#define	FLS3		BIT_3
#define	FLS4		BIT_4
#define	FLS5		BIT_5
#define	FLS6		BIT_6
#define	FLS7		BIT_7

#define	FLG1		BIT_9
#define	FLG2		BIT_10
#define	FLG3		BIT_11
#define	FLG4		BIT_12
#define	FLG5		BIT_13
#define	FLG6		BIT_14
#define	FLG7		BIT_15

		// Definition for SPISTx B-58
#define	SPI_SPIF		BIT_0
#define SPI_MODF		BIT_1
#define SPI_TXE			BIT_2
#define SPI_TXS			BIT_3
#define SPI_RBSY		BIT_4
#define SPI_RXS			BIT_5
#define SPI_TXCOL		BIT_6



//*********************************************************************
//
//
//									TIMER
//
//
//*********************************************************************
		// Definition for T_GSR
#define	TIMDIS2		BIT_13
#define	TIMEN2		BIT_12
#define	TIMDIS1		BIT_11
#define	TIMEN1		BIT_10
#define	TIMDIS0		BIT_9
#define	TIMEN0		BIT_8
#define	OVF_ERR2	BIT_6
#define	OVF_ERR1	BIT_5
#define	OVF_ERR0	BIT_4
#define	TIMIL2		BIT_2
#define	TIMIL1		BIT_1
#define	TIMIL0		BIT_0

		// Definition for TCFGR
#define	TIN_SEL		BIT_5
#define	IRQ_ENA		BIT_4
#define	PERIOD_CNT	BIT_3
#define	PULSE_HI	BIT_2
#define TMODE_OFST	0
#define	TMODE_MASK	( 0x3 << TIMOD_OFST )
#define	TMODE_PWMOUT	( 1 << TIMOD_OFST )
#define	TMODE_WIDTHCAP	( 2 << TIMOD_OFST )
#define	TMODE_EXTCLK	( 3 << TIMOD_OFST )


//*********************************************************************
//
//
//							UART
//									contributed by Benno Kusstatscher
//
//*********************************************************************


//IER 			/* Interupt Enable Register */
#define EDSSI		BIT_3	/* Ena Modem Status Int */
#define ELSI		BIT_2	/* Ena Line status int */
#define ETBEI		BIT_1	/* Ena Xmit Buf Empty int */
#define ERBFI		BIT_0	/* Ena Rx buffer rdy int */


// IIR 			/* Interrupt Identification Reg */
#define NINT		BIT_0    /* No Interrupt */
#define	STATUS_OFST 1
#define STATUS_MASK ( 3 << STATUS_OFST )
#define STATUS_RX_LS	( 3 << STATUS_OFST )	/* Rx Line Status Interrupt */
#define STATUS_RX_DRY	( 2 << STATUS_OFST )	/* RX Data Ready in RBR */
#define STATUS_TX_RDY	( 1 << STATUS_OFST )	/* THR Ready for new data */
#define STATUS_MSC		( 0 << STATUS_OFST )	/* Modem Status changed */

// LCR			/* Line Control Register */
#define   DLAB		BIT_7	/* Divisor Latch (DLL and DLH) Access Bit */
#define   BRK		BIT_6	/* Break. Force TX low */
#define   SP		BIT_5	/* Stick Parity */
#define   EPS		BIT_4	/* Even Parity Select */
#define   PEN		BIT_3	/* Parity Enable */
#define   STB		BIT_2	/* Stop Bit Number Selector  */
#define	  WLS_OFST  0
#define   WLS_MASK	( 0x3 << WLS_OFST )
#define   WLS5CHAR	( 0x0 << WLS_OFST )    /* Word length of 5 Bits */
#define   WLS6CHAR	( 0x1 << WLS_OFST )    /* Word length of 6 Bits */
#define   WLS7CHAR	( 0x2 << WLS_OFST )    /* Word length of 7 Bits */
#define   WLS8CHAR	( 0x3 << WLS_OFST )    /* Word length of 8 Bits */

// MCR			/* Modem Control Register */
#define	  LOOP		BIT_4	/* Loopback test mode. Force Tx Hi */
#define	  OUT2		BIT_3	/* GPIO */
#define	  OUT1		BIT_2	/* GPIO */
#define	  RTS		BIT_1	/* Ready to send */
#define	  DTR		BIT_0	/* Data Terminal Ready */

// LSR			/* Line Status Register */
#define   TEMT		BIT_6	/* THR and TSR empty */
#define   THRE		BIT_5	/* THR empty */
#define   BI		BIT_4	/* RX Break Interrupt (RX held low) detected.  */
#define   FE		BIT_3	/* RX Framing Error */
#define   PE		BIT_2	/* RX Parity Error */
#define   OE		BIT_1	/* RX Overrun Error */
#define   DR		BIT_0	/* Data Ready in RBR */

// MSR 			/* Modem Status Register */
#define	  DCD		BIT_7	/* Data Carrier Detect */
#define	  RI		BIT_6	/* Ring Indicator */
#define   DSR		BIT_5	/* Data Set Ready */
#define   CTS		BIT_4	/* Clear To Send */
#define   DDCD		BIT_3	/* DCD has changed */
#define   TERI		BIT_2	/* Trailing Edge RI */
#define   DDSR		BIT_1	/* DSR has changed */
#define   DCTS		BIT_0	/* CTS has changed */

//*********************************************************************
//
//
//						Clock and System Control
//
//
//*********************************************************************

//definition of PLLCTL. HR B-15
#define	MSEL6			BIT_15
#define	MSEL5			BIT_14
#define	MSEL40_OFST		9
#define	MSEL40_MASK		( 0x1f << MSEL40_OFST )
#define	MSEL40_0		( 0 << MSEL40_OFST )
#define	MSEL40_1		( 1 << MSEL40_OFST )
#define	MSEL40_2		( 2 << MSEL40_OFST )
#define	MSEL40_3		( 3 << MSEL40_OFST )
#define	MSEL40_4		( 4 << MSEL40_OFST )
#define	MSEL40_5		( 5 << MSEL40_OFST )
#define	MSEL40_6		( 6 << MSEL40_OFST )
#define	MSEL40_7		( 7 << MSEL40_OFST )
#define	MSEL40_8		( 8 << MSEL40_OFST )
#define	MSEL40_9		( 9 << MSEL40_OFST )
#define	MSEL40_10		( 10 << MSEL40_OFST )
#define	MSEL40_11		( 11 << MSEL40_OFST )
#define	MSEL40_12		( 12 << MSEL40_OFST )
#define	MSEL40_13		( 13 << MSEL40_OFST )
#define	MSEL40_14		( 14 << MSEL40_OFST )
#define	MSEL40_15		( 15 << MSEL40_OFST )
#define	MSEL40_16		( 16 << MSEL40_OFST )
#define	MSEL40_17		( 17 << MSEL40_OFST )
#define	MSEL40_18		( 18 << MSEL40_OFST )
#define	MSEL40_19		( 19 << MSEL40_OFST )
#define	MSEL40_20		( 20 << MSEL40_OFST )
#define	MSEL40_21		( 21 << MSEL40_OFST )
#define	MSEL40_22		( 22 << MSEL40_OFST )
#define	MSEL40_23		( 23 << MSEL40_OFST )
#define	MSEL40_24		( 24 << MSEL40_OFST )
#define	MSEL40_25		( 25 << MSEL40_OFST )
#define	MSEL40_26		( 26 << MSEL40_OFST )
#define	MSEL40_27		( 27 << MSEL40_OFST )
#define	MSEL40_28		( 28 << MSEL40_OFST )
#define	MSEL40_29		( 29 << MSEL40_OFST )
#define	MSEL40_30		( 30 << MSEL40_OFST )
#define	MSEL40_31		( 31 << MSEL40_OFST )
#define BYPASS			BIT_8	
#define	DIV2			BIT_7
#define	CKOUTEN			BIT_6
#define	PDWN			BIT_5
#define	IOSEL			BIT_4
#define	STOPCK			BIT_3
#define	STOPALL			BIT_2
#define	PO				BIT_1
#define	DF 				BIT_0

// Definition of NXTSCR HR B-18
// Too avoid the trouble. BMODE_MASK and BMODE_OFST is not defined.
// Be careful that this definition takes 3 bits for BMODE, instead
// HR B-18 gives only 2 bits.
#define PFMODE			BIT_5
#define	RMODE			BIT_4
#define	BMODE_NOBOOT16	0x0000
#define	BMODE_EPROM8	BIT_1
#define	BMODE_HOST		BIT_2
#define	BMODE_NOBOOT8	BIT_0
#define	BMODE_UART		0x0003
#define	BMODE_SPI4K		0x0005
#define	BMODE_SPI512K	0x0007

// Definition for SYSCR
#define OPMODE			BIT_0

//*********************************************************************
//
//
//						Interrupt Control
//
//
//*********************************************************************

// Definition of IPR0
#define	SP1RXIP_OFST	12
#define SP1RXIP_MASK	0xf000
#define	SP0TXIP_OFST	8
#define SP0TXIP_MASK	0x0f00
#define	SP0RXIP_OFST	4
#define SP0RXIP_MASK	0x00f0
#define	HOSTIP_OFST		0
#define HOSTIP_MASK		0x000f


// Definition of IPR1
#define	UARRXIP_OFST	12
#define UARRXIP_MASK	0xf000
#define	SP2TXIP_OFST	8
#define SP2TXIP_MASK	0x0f00
#define	SP2RXIP_OFST	4
#define SP2RXIP_MASK	0x00f0
#define	SP1TXIP_OFST	0
#define SP1TXIP_MASK	0x000f


// Definition of IPR2
#define	TIMER2IP_OFST	12
#define TIMER2IP_MASK	0xf000
#define	TIMER1IP_OFST	8
#define TIMER1IP_MASK	0x0f00
#define	TIMER0IP_OFST	4
#define TIMER0IP_MASK	0x00f0
#define	UARTXIP_OFST	0
#define UARTXIP_MASK	0x000f


// Definition of IPR3
#define	MDMAIP_OFST	8
#define MDMAIP_MASK	0x0f00
#define	FLAGBIP_OFST 4
#define FLAGBIP_MASK 0x00f0
#define	FLAGAIP_OFST 0
#define FLAGAIP_MASK 0x000f

// Definition of INTRDx
// Note : The bit name is not defined HR. I have defined from IPRx
#define MDMA_INT	BIT_14
#define FLAGB_INT	BIT_13
#define FLAGA_INT	BIT_12
#define TIMER2_INT	BIT_11
#define TIMER1_INT	BIT_10
#define TIMER0_INT	BIT_9
#define UARTX_INT	BIT_8
#define UARRX_INT	BIT_7
#define SP2TX_INT	BIT_6
#define SP2RX_INT	BIT_5
#define SP1TX_INT	BIT_4
#define SP1RX_INT	BIT_3
#define SP0TX_INT	BIT_2
#define SP0RX_INT	BIT_1
#define HOST_INT	BIT_0

//*********************************************************************
//
//
//									External PORT
//
//
//*********************************************************************

// Definition for E_STAT (HR B-92)
#define E_WPF			BIT_8
#define E_DFS			BIT_3
#define E_DD_BE			BIT_2
#define	E_PD_BE			BIT_1
#define	E_PI_BE			BIT_0

//Definition for EMICTL (HR B-93)
#define E_ASE			BIT_6
#define E_RLS			BIT_5
#define E_WLS			BIT_4
#define	E_BWS			BIT_3
#define	E_CRL			BIT_2
#define	E_BHE			BIT_1
#define	E_BL			BIT_0

// Definition for BMSCTL (HR B-94)
#define E_COE			BIT_15
#define E_WHC			BIT_11
#define E_CDS_OFST		8
#define E_CDS_MASK		( 0x7 << E_CDS_OFST )
#define E_CDS_1x		( 0 << E_CDS_OFST )
#define E_CDS_2x		( 1 << E_CDS_OFST )
#define E_CDS_4x		( 2 << E_CDS_OFST )
#define E_CDS_8x		( 3 << E_CDS_OFST )
#define E_CDS_16x		( 4 << E_CDS_OFST )
#define E_CDS_32x		( 5 << E_CDS_OFST )
#define E_WMS_OFST		6
#define	E_WMS_MASK		( 0x3 << E_WMS_OFST )
#define E_WMS_EXT		( 0 << E_WMS_OFST )
#define E_WMS_INT		( 1 << E_WMS_OFST )
#define E_WMS_BOTH		( 2 << E_WMS_OFST )
#define E_WMS_EITHER	( 3 << E_WMS_OFST )
#define E_WWC_OFST		3
#define E_WWC_MASK		( 0x3 << E_WWC_OFST )
#define E_WWC_0			( 0 << E_WWC_OFST )
#define E_WWC_1			( 1 << E_WWC_OFST )
#define E_WWC_2			( 2 << E_WWC_OFST )
#define E_WWC_3			( 3 << E_WWC_OFST )
#define E_WWC_4			( 4 << E_WWC_OFST )
#define E_WWC_5			( 5 << E_WWC_OFST )
#define E_WWC_6			( 6 << E_WWC_OFST )
#define E_WWC_7			( 7 << E_WWC_OFST )
#define E_RWC_OFST		0
#define E_RWC_MASK		( 0x7 << E_RWC_OFST )
#define	E_RWC_0			( 0 << E_RWC_OFST )
#define	E_RWC_1			( 1 << E_RWC_OFST )
#define	E_RWC_2			( 2 << E_RWC_OFST )
#define	E_RWC_3			( 3 << E_RWC_OFST )
#define	E_RWC_4			( 4 << E_RWC_OFST )
#define	E_RWC_5			( 5 << E_RWC_OFST )
#define	E_RWC_6			( 6 << E_RWC_OFST )
#define	E_RWC_7			( 7 << E_RWC_OFST )

//Definition for EMISTAT (HR B-98)
#define E_WPS_OFST		7
#define E_WPS_MASK		( 3 << E_WPS_OFST )
#define E_MID_OFST		2
#define E_MID_MASK		( 0x1f << E_MID_OFST )
#define E_BSY_OFST		0
#define E_BSY_MASK		( 0x3 << E_BSY_OFST )


//*********************************************************************
//
//
//									HPCR
//
//
//*********************************************************************


// Definition for HPCR (HR B-101)
#define H_ALES			BIT_11
#define H_ACKS			BIT_10
#define H_WLS			BIT_9
#define	H_RLS			BIT_8
#define	H_AMS_OFST		6
#define H_AMS_MASK		( 0x3 << H_AMS_OFST )
#define H_AMS_ACK		( 0 << H_AMS_OFST )
#define H_AMS_READY		( 1 << H_AMS_OFST )
#define H_PFET			BIT_5
#define	H_PRED			BIT_4
#define	H_PSIZE			BIT_3
#define H_DORD			BIT_2
#define	H_BEND			BIT_1
#define	H_BWS			BIT_0


//Definition of HPPR	(HR B-104)
#define HPPR_MP_OFST	7
#define HPPR_MP_MASK	( 0x1f << HPPR_MP_OFST )
#define HPPR_DTYPE		BIT_1
#define HPPR_MS			BIT_0


